@@ -1,6 +1,6 @@
-#' Read Tabulated Files Exported by FragPipe At Protein Level
+#' Read Tabulated Files Exported by FragPipe At Protein Level2
 #'
-#' This function allos importing protein identification and quantification results form \href{https://fragpipe.nesvilab.org/}{Fragpipe}
+#' This function allows importing protein identification and quantification results from \href{https://fragpipe.nesvilab.org/}{Fragpipe}
 #' which were previously exported as tabulated text (tsv). Quantification data and other relevant information will be extracted similar like the other import-functions from this package.
 #' The final output is a list containing the elements: \code{$annot}, \code{$raw} and \code{$quant}, or a data.frame with the quantication data and a part of the annotation if argument \code{separateAnnot=FALSE}.
 #'
@@ -12,32 +12,33 @@
 #' @param fileName (character) name of file to be read
 #' @param path (character) path of file to be read
 #' @param normalizeMeth (character) normalization method, defaults to \code{median}, for more details see \code{\link[wrMisc]{normalizeThis}})
-#' @param sampleNames (character) new column-names for quantification data (ProteomeDiscoverer does not automatically use file-names from spectra); this argument has priority over \code{suplAnnotFile}
+#' @param sampleNames (character) custom column-names for quantification data; this argument has priority over \code{suplAnnotFile}
 #' @param read0asNA (logical) decide if initial quntifications at 0 should be transformed to NA (thus avoid -Inf in log2 results)
 #' @param quantCol (character or integer) exact col-names, or if length=1 content of \code{quantCol} will be used as pattern to search among column-names for $quant using \code{grep}
 #' @param refLi (character or integer) custom specify which line of data is main species, if character (eg 'mainSpe'), the column 'SpecType' in $annot will be searched for exact match of the (single) term given
 #' @param separateAnnot (logical) if \code{TRUE} output will be organized as list with \code{$annot}, \code{$abund} for initial/raw abundance values and \code{$quant} with final log2 (normalized) quantitations
 #' @param annotCol (character) column names to be read/extracted for the annotation section (default  c("Accession","Description","Gene","Contaminant","Sum.PEP.Score","Coverage....","X..Peptides","X..PSMs","X..Unique.Peptides", "X..AAs","MW..kDa.") )
 #' @param FDRCol (list) optional indication to search for protein FDR information
-#' @param tit (character) custom title to plot
-#' @param graphTit (character) depreciated custom title to plot, please use 'tit'
 #' @param wex (integer) relative expansion factor of the violin-plot (will be passed to \code{\link[wrGraph]{vioplotW}})
 #' @param specPref (character or list) define characteristic text for recognizing (main) groups of species (1st for comtaminants - will be marked as 'conta', 2nd for main species- marked as 'mainSpe',
 #'  and optional following ones for supplemental tags/species - maked as 'species2','species3',...);
 #'  if list and list-element has multiple values they will be used for exact matching of accessions (ie 2nd of argument \code{annotCol})
 #' @param gr (character or factor) custom defined pattern of replicate association, will override final grouping of replicates from \code{sdrf} and/or \code{suplAnnotFile} (if provided)   \code{}
-#' @param sdrf (character, list or data.frame) optional extraction and adding of experimenal meta-data: if character, this may be the ID at ProteomeExchange. Besides, the output from \code{readSdrf} or a list from \code{defineSamples} may be provided; if \code{gr} is provided, it gets priority for grouping of replicates
+#' @param sdrf (character, list or data.frame) optional extraction and adding of experimenal meta-data: if character, this may be the ID at ProteomeExchange, 
+#'   the second element may give futher indicatations for automatic organization of groups of replicates. 
+#'   Besides, the output from \code{readSdrf} or a list from \code{defineSamples} may be provided; if \code{gr} is provided, \code{gr} gets priority for grouping of replicates
 #' @param suplAnnotFile (logical or character) optional reading of supplemental files; however, if \code{gr} is provided, \code{gr} gets priority for grouping of replicates;
 #'  if \code{character} the respective file-name (relative or absolute path)
 #' @param groupPref (list) additional parameters for interpreting meta-data to identify structure of groups (replicates), will be passed to \code{readSampleMetaData}.
 #'   May contain \code{lowNumberOfGroups=FALSE} for automatically choosing a rather elevated number of groups if possible (defaults to low number of groups, ie higher number of samples per group)
 #' @param plotGraph (logical or integer) optional plot of type vioplot of initial and normalized data (using \code{normalizeMeth}); if integer, it will be passed to \code{layout} when plotting
+#' @param titGraph (character) custom title to plot of distribution of quantitation values
 #' @param silent (logical) suppress messages
 #' @param debug (logical) additional messages for debugging
 #' @param callFrom (character) allow easier tracking of messages produced
 #' @return This function returns a list with \code{$raw} (initial/raw abundance values), \code{$quant} with final normalized quantitations, \code{$annot}, \code{$counts} an array with number of peptides, \code{$quantNotes}
 #'  and \code{$notes}; or if \code{separateAnnot=FALSE} the function returns a data.frame with annotation and quantitation only
-#' @seealso \code{\link[utils]{read.table}}, \code{\link[wrMisc]{normalizeThis}}) , \code{\link{readMaxQuantFile}}, \code{\link{readProlineFile}}
+#' @seealso \code{\link[utils]{read.table}}, \code{\link[wrMisc]{normalizeThis}}) , \code{\link{readMaxQuantFile}}, \code{\link{readProtDiscovFile}}, \code{\link{readProlineFile}}
 #' @examples
 #' FPproFi1 <- "tinyFragpipe1.tsv.gz"
 #' path1 <- system.file("extdata", package="wrProteo")
@@ -49,7 +50,7 @@
 #' @export
 readFragpipeFile <- function(fileName, path=NULL, normalizeMeth="median", sampleNames=NULL, read0asNA=TRUE, quantCol="Intensity$",
   annotCol=NULL,  refLi=NULL, separateAnnot=TRUE, FDRCol=list("Protein.Probability", lim=0.99),    # contamCol="Contaminant",
-  groupPref=list(lowNumberOfGroups=TRUE), plotGraph=TRUE, tit="FragPipe", graphTit=NULL, wex=1.6, specPref=c(conta="CON_|LYSC_CHICK", mainSpecies="OS=Homo sapiens"),
+  groupPref=list(lowNumberOfGroups=TRUE), plotGraph=TRUE, titGraph="FragPipe", wex=1.6, specPref=c(conta="CON_|LYSC_CHICK", mainSpecies="OS=Homo sapiens"),
   gr=NULL, sdrf=NULL, suplAnnotFile=FALSE, silent=FALSE, debug=FALSE, callFrom=NULL) {
 
   ## read Fragpipe exported txt
@@ -92,7 +93,7 @@ readFragpipeFile <- function(fileName, path=NULL, normalizeMeth="median", sample
   ## future: look for fast reading of files
   tmp <- try(utils::read.delim(file.path(paFi), stringsAsFactors=FALSE), silent=TRUE)
 
-  if(length(tmp) <1 | inherits(tmp, "try-error") | length(dim(tmp)) <2) {
+  if(length(tmp) <1 || inherits(tmp, "try-error") || length(dim(tmp)) <2) {
     if(inherits(tmp, "try-error")) warning("Unable to read input file ('",paFi,"')!  (check if rights to read)") else {
       if(!silent) message(fxNa,"Content of  file '",paFi,"' seeps empty or non-conform !  Returning NULL; check if this is really a Fragpipe-file") }
     NULL
@@ -113,17 +114,17 @@ readFragpipeFile <- function(fileName, path=NULL, normalizeMeth="median", sample
       ## check in 'matr' for column-name 'x', if required rename best hit (if no direct hit look using grep, then grep wo case); return corrected mat
       chX <- x %in% colnames(mat)
       if(all(chX)) {
-        if(is.character(renameTo) & length(renameTo) ==1) colnames(mat)[match(x, colnames(mat))] <- renameTo   # juste simple rename (single col only)
+        if(is.character(renameTo) && length(renameTo) ==1) colnames(mat)[match(x, colnames(mat))] <- renameTo   # juste simple rename (single col only)
       } else {     # try to localize column to use
         chX <- grep(x, colnames(mat))
         if(length(chX) >0) {
-          if(is.character(renameTo) & length(renameTo) ==1) colnames(mat)[chX[1]] <- renameTo else x
-          if(!silent & length(chX) >1) message(fxNa,"Found multiple columns containing '",x,"' : ",wrMisc::pasteC(colnames(mat)[chX], quoteC="'"),", using 1st")
+          if(is.character(renameTo) && length(renameTo) ==1) colnames(mat)[chX[1]] <- renameTo else x
+          if(!silent && length(chX) >1) message(fxNa,"Found multiple columns containing '",x,"' : ",wrMisc::pasteC(colnames(mat)[chX], quoteC="'"),", using 1st")
         } else {
           chX <- grep(tolower(x), tolower(colnames(mat)))
           if(length(chX) >0) {
-            if(is.character(renameTo) & length(renameTo) ==1) colnames(mat)[chX[1]] <- renameTo else x
-            if(!silent & length(chX) >1) message(fxNa,"Found multiple columns containing '",tolower(x),"' : ",wrMisc::pasteC(colnames(mat)[chX], quoteC="'"),", using 1st")
+            if(is.character(renameTo) && length(renameTo) ==1) colnames(mat)[chX[1]] <- renameTo else x
+            if(!silent && length(chX) >1) message(fxNa,"Found multiple columns containing '",tolower(x),"' : ",wrMisc::pasteC(colnames(mat)[chX], quoteC="'"),", using 1st")
           } else stop("Could NOT find column '",x,"' !!\n  (available columns ",wrMisc::pasteC(colnames(mat), quoteC="'"),")") }
       }
     mat }
@@ -141,9 +142,9 @@ readFragpipeFile <- function(fileName, path=NULL, normalizeMeth="median", sample
       Description=tmp[,"Description"], tmp[,wrMisc::naOmit(annotColNo[-(1:6)])])   # may be better to name column 'species'
     if(debug) { message(fxNa,"rfp2 .. annotColNo : ", wrMisc::pasteC(annotColNo)); rfp2 <- list(annot=annot,annotCol=annotCol,tmp=tmp,specPref=specPref )}
 
-    ## Species  (need to run before reparsing nadly parsed)
+    ## Species  (need to run before reparsing badly parsed)
     if(!is.na(annotColNo[6])) { spec <- tmp[,annotColNo[6]]
-      spec <- sub("^\ +|\ +$","",spec)          # remove heading or tailing (white) space
+      spec <- sub("^\ +|\ +$","", spec)          # remove heading or tailing (white) space
       chOX <- grep(" OX=", spec)
       if(length(chOX) >0) { OX <- sub(" OX=", "", spec[chOX])
         spec[chOX] <- sub(" OX=[[:digit:]]+[[:print:]]*","", spec[chOX])
@@ -184,14 +185,14 @@ readFragpipeFile <- function(fileName, path=NULL, normalizeMeth="median", sample
       annot[,"Description"] <- sub(" \\([[:alpha:]]*$", "", annot[,"Description"])                  # tailing (ie truncated) open '(xxx'
     }
 
-    if(debug) { message(fxNa,"rfp3b"); rfp3b <- list(annot=annot,tmp=tmp,specPref=specPref,annotCol=annotCol,PSMCol=PSMCol,PepCol=PepCol) }
+    if(debug) { message(fxNa,"rfp3b"); rfp3b <- list() }
 
     if(debug) {message(fxNa,"rfp4 .. dim annot: ", nrow(annot)," li and  ",ncol(annot)," cols; colnames : ",wrMisc::pasteC(colnames(annot))," ")}
     .MultGrep <- function(pat, y) if(length(pat)==1) grep(pat, y) else unlist(sapply(pat, grep, y))  # (multiple) grep() when length of pattern 'pat' >0
 
     ## Contam
     if("Contaminant" %in% colnames(annot)) {                         # just in case there is a column called 'Contaminant' (so far not seen)
-      useLi <- which[nchar(annot[,"Contaminant"]) >0 & !is.na(annot[,"Contaminant"])]
+      useLi <- which[nchar(annot[,"Contaminant"]) >0 && !is.na(annot[,"Contaminant"])]
       if(length(useLi) >0) annot[useLi,"Contam"] <- toupper(gsub(" ","",annot[useLi,"Contaminant"]))}
     chConta <- grep("^contam", tmp[,annotCol[1]])                    # specific to  Fragpipe
     if(length(chConta) >0) annot[chConta,"Contam"] <- TRUE
@@ -217,7 +218,7 @@ readFragpipeFile <- function(fileName, path=NULL, normalizeMeth="median", sample
     if(debug) {message(fxNa,"rfp6b ..  ")}
 
     if(!silent) {
-      if(any(chSp, na.rm=TRUE) & !all(chSp)) message(fxNa,"Note: ",sum(chSp)," (out of ",nrow(tmp),") lines with unrecognized species")
+      if(any(chSp, na.rm=TRUE) && !all(chSp)) message(fxNa,"Note: ",sum(chSp)," (out of ",nrow(tmp),") lines with unrecognized species")
       if(!all(chSp)) { tab <- table(annot[,"Species"])
         tab <- rbind(names(tab), paste0(": ",tab," ;  "))
         if(!silent) message(fxNa,"Count by 'specPref' : ",apply(tab, 2, paste)) }}             # all lines assigned
@@ -243,7 +244,7 @@ readFragpipeFile <- function(fileName, path=NULL, normalizeMeth="median", sample
       useMaxLFQItens <- FALSE
       quantColIni <- quantCol <- grep(quantCol, colnames(tmp))
       chLFQ <- grep("MaxLFQ\\.", colnames(tmp)[quantCol])
-      if(length(chLFQ) >0) { if(!silent & length(chLFQ)==length(quantCol)) message(fxNa,"All quantification columns are MaxLFQ !")
+      if(length(chLFQ) >0) { if(!silent && length(chLFQ)==length(quantCol)) message(fxNa,"All quantification columns are MaxLFQ !")
         if(length(chLFQ) < length(quantCol)) quantCol <- quantCol[(if(useMaxLFQItens) 1 else -1) *chLFQ] else warning("No non-MaxLFQ data available, using MaxLFQ.Intensity instead !") }
     }
     if(length(quantCol) <1) stop(msg,"  ('",quantCol,"')")
@@ -254,8 +255,8 @@ readFragpipeFile <- function(fileName, path=NULL, normalizeMeth="median", sample
     ## check & clean abundances
 
     ## add custom sample names (if provided)
-    if(length(sampleNames) ==ncol(abund) & ncol(abund) >0) {
-      if(debug) { message(fxNa,"rfp8b") }
+    if(length(sampleNames) ==ncol(abund) && ncol(abund) >0) {
+      if(debug) { message(fxNa,"Valid 'sampleNames' were provided   rfp8b") }
       if(length(unique(sampleNames)) < length(sampleNames)) {
         if(!silent) message(fxNa,"Custom sample names not unique, correcting to unique")
         sampleNames <- wrMisc::correctToUnique(sampleNames, callFrom=fxNa) }
@@ -302,125 +303,58 @@ readFragpipeFile <- function(fileName, path=NULL, normalizeMeth="median", sample
       rfp12 <- list(tmp=tmp,abund=abund,annot=annot,sdrf=sdrf, fileName=fileName,path=path,paFi=paFi,normalizeMeth=normalizeMeth,sampleNames=sampleNames,
             refLi=refLi,specPref=specPref,read0asNA=read0asNA,quantCol=quantCol,annotCol=annotCol,refLi=refLi,separateAnnot=separateAnnot,FDRCol=FDRCol,gr=gr) }
 
+    ## correct colnames from 'Xabc_1.Intensity' to 'abc_1'
+    ch1 <- grepl("^X[[:digit:]]", colnames(abund))
+    if(any(ch1)) colnames(abund)[which(ch1)] <- sub("^X","", colnames(abund)[which(ch1)])
+    colnames(abund) <- sub("\\.Intensity$","", colnames(abund))
 
     ## check for reference for normalization
     refLiIni <- refLi
-    if(is.character(refLi) & length(refLi)==1) { refLi <- which(annot[,"SpecType"]==refLi)
-      if(length(refLi) <1 & !silent) message(fxNa,"Could not find any protein matching argument 'refLi', ignoring ...") else {
+    if(is.character(refLi) && length(refLi)==1) {
+      refLi <- which(annot[,"SpecType"]==refLi)
+      if(length(refLi) <1 ) { refLi <- 1:nrow(abund)
+        if(!silent) message(fxNa,"Could not find any proteins matching argument 'refLi=",refLiIni,"', ignoring ...")
+      } else {
         if(!silent) message(fxNa,"Normalize using (custom) subset of ",length(refLi)," lines specified as '",refLiIni,"'")}}    # may be "mainSpe"
-    if(length(refLi) <1) refLi <- 1:nrow(abund)
 
     ## set 0 values to NA (avoid -Inf at log2)
     if(!isFALSE(read0asNA)) { ch0 <- abund ==0
       if(any(ch0, na.rm=TRUE)) abund[which(ch0)] <- NA }
 
     ## take log2 & normalize
-    quant <- if(utils::packageVersion("wrMisc") > "1.10") {
-        try(wrMisc::normalizeThis(log2(abund), method=normalizeMeth, mode="additive", refLines=refLi, silent=silent, callFrom=fxNa), silent=TRUE)
-      } else try(wrMisc::normalizeThis(log2(abund), method=normalizeMeth, refLines=refLi, silent=silent, callFrom=fxNa), silent=TRUE)       #
+    quant <- try(wrMisc::normalizeThis(log2(abund), method=normalizeMeth, mode="additive", refLines=refLi, silent=silent, callFrom=fxNa), silent=TRUE)  
     if(debug) { message(fxNa,"rfp13 .. dim quant: ", nrow(quant)," li and  ",ncol(quant)," cols; colnames : ",wrMisc::pasteC(colnames(quant))," ")
-      rfp13 <- list(tmp=tmp,quant=quant,abund=abund,annot=annot,sdrf=sdrf, fileName=fileName,path=path,paFi=paFi,normalizeMeth=normalizeMeth,sampleNames=sampleNames,
-            refLi=refLi,specPref=specPref,read0asNA=read0asNA,quantCol=quantCol,annotCol=annotCol,refLi=refLi,separateAnnot=separateAnnot,FDRCol=FDRCol,gr=gr) }
+      rfp13 <- list(tmp=tmp,quant=quant,abund=abund,annot=annot,sdrf=sdrf, fileName=fileName,path=path,paFi=paFi,normalizeMeth=normalizeMeth,sampleNames=sampleNames,groupPref=groupPref,
+            refLi=refLi,refLiIni=refLiIni,specPref=specPref,read0asNA=read0asNA,quantCol=quantCol,annotCol=annotCol,separateAnnot=separateAnnot,FDRCol=FDRCol,gr=gr,silent=silent,debug=debug) }
 
     ### GROUPING OF REPLICATES AND SAMPLE META-DATA
-    if(any((!isFALSE(suplAnnotFile) & length(suplAnnotFile) >0), length(sdrf) >0)) {
-      setupSd <- readSampleMetaData(sdrf=sdrf, suplAnnotFile=suplAnnotFile, quantMeth="FP", path=path, abund=utils::head(quant), groupPref=groupPref, silent=silent, debug=debug, callFrom=fxNa)
+    if(length(suplAnnotFile) >0 || length(sdrf) >0) {
+      #setupSd <- readSampleMetaData(sdrf=rfp13$sdrf, suplAnnotFile=T, quantMeth="FP", path=rfp13$path, abund=utils::head(rfp13$quant), groupPref=rfp13$groupPref, silent=rfp13$silent, debug=rfp13$debug, callFrom="readFP")
+      setupSd <- readSampleMetaData(sdrf=sdrf, suplAnnotFile=separateAnnot, quantMeth="FP", path=path, abund=utils::head(quant), groupPref=groupPref, silent=silent, debug=debug, callFrom=fxNa)
     }
-    if(debug) {message(fxNa,"rfp13b"); rfp13b <- list(tmp=tmp,quant=quant,abund=abund,setupSd=setupSd,annot=annot,sdrf=sdrf, fileName=fileName,path=path,paFi=paFi,normalizeMeth=normalizeMeth,sampleNames=sampleNames,
-            specPref=specPref,read0asNA=read0asNA,quantCol=quantCol,annotCol=annotCol,refLi=refLi,separateAnnot=separateAnnot,FDRCol=FDRCol, gr=gr )}
+    if(debug) {message(fxNa,"rfp13b .."); rfp13b <- list()}
 
     ## finish groups of replicates & annotation setupSd
-    if(length(setupSd) >0 & length(setupSd$groups) <1) {                       # if nothing found/matching from sdrf & file, try getting sample-setup from colnames (use if at least 1 replicate found)
-      if(length(gr) ==ncol(abund)) setupSd$groups <- gr else {
-        if(debug) {message(fxNa,"rfp13e  Note: setupSd$groups is still empty ! ")}
-        if(length(setupSd$lev) ==ncol(abund)) setupSd$groups <- setupSd$lev else {
-          if(length(setupSd$lev) >0 & ncol(abund) >0) warning(fxNa," sdrf sample-metadata dot not fit (sdrf suggests ",length(setupSd$lev)," but real data consist of ",ncol(abund)," samples) !")
-          ## try defining groups based on colnames
-          if(debug) {message(fxNa,"rfp13f  Note: setupSd$lev is still empty/not matching !  .. try getting sample-setup from colnames");
-            rfp13f <- list(tmp=tmp,quant=quant,abund=abund,setupSd=setupSd,annot=annot,sdrf=sdrf, ileName=fileName,path=path,paFi=paFi,tmp=tmp,normalizeMeth=normalizeMeth,sampleNames=sampleNames,
-            read0asNA=read0asNA,quantCol=quantCol,annotCol=annotCol,refLi=refLi,separateAnnot=separateAnnot,FDRCol=FDRCol )}
-          delPat <- "_[[:digit:]]+$|\\ [[:digit:]]+$|\\-[[:digit:]]+$"       # remove enumerators, ie trailing numbers after separator
-          grou <- sub(delPat,"", colnames(abund))
-          if(length(unique(grou)) >1 & length(unique(grou)) < ncol(abund)) setupSd$groups <- grou else {
-            grou <- sub("[[:digit:]]+$","", colnames(abund))
-            if(length(unique(grou)) >1 & length(unique(grou)) < ncol(abund)) setupSd$groups <- grou }
-        } }
-    }
-    if(debug) {message(fxNa,"rfp13g"); rfp13g <- list(tmp=tmp,quant=quant,abund=abund,setupSd=setupSd,annot=annot,sdrf=sdrf, ileName=fileName,path=path,paFi=paFi,tmp=tmp,normalizeMeth=normalizeMeth,sampleNames=sampleNames,
-            read0asNA=read0asNA,quantCol=quantCol,annotCol=annotCol,refLi=refLi,separateAnnot=separateAnnot,FDRCol=FDRCol )}
+    setupSd <- .checkSetupGroups(abund=abund, setupSd=setupSd, gr=gr, sampleNames=sampleNames, quantMeth="FP", silent=silent, debug=debug, callFrom=fxNa)
+    colnames(quant) <- colnames(abund) <- if(length(setupSd$sampleNames)==ncol(abund)) setupSd$sampleNames else setupSd$groups
+    if(length(dim(counts)) >1 && length(counts) >0) colnames(counts) <- setupSd$sampleNames
 
-    ## finish sample-names: use file-names from meta-data if no custom 'sampleNames' furnished
-    ## One more check for colnames & sampleNames
-    if(length(sampleNames) <1) sampleNames <- wrMisc::trimRedundText(
-       if(length(setupSd$sdrfDat$comment.data.file.) ==ncol(abund)) setupSd$sdrfDat$comment.data.file. else colnames(abund), minNchar=2, spaceElim=TRUE, silent=silent, callFrom=fxNa, debug=debug)
+    if(debug) {message(fxNa,"Read sample-meta data, rfp14"); rfp14 <- list(setupSd=setupSd, sdrf=sdrf, suplAnnotFile=suplAnnotFile,quant=quant,abund=abund,plotGraph=plotGraph)}
 
-    if(debug) {message(fxNa,"rfp13h"); rfp13h <- list(tmp=tmp,quant=quant,abund=abund,setupSd=setupSd,annot=annot,sdrf=sdrf, fileName=fileName,path=path,paFi=paFi,tmp=tmp,normalizeMeth=normalizeMeth,sampleNames=sampleNames,
-            read0asNA=read0asNA,quantCol=quantCol,annotCol=annotCol,refLi=refLi,separateAnnot=separateAnnot,FDRCol=FDRCol )}
-
-    if(length(sampleNames) == ncol(quant)) {
-      colnames(quant) <- colnames(abund) <- sampleNames     # use custom provided sampleNames
-      if(length(dim(counts)) >1 & length(counts) >0) colnames(counts) <- sampleNames
-    } else {
-      if(debug) { message(fxNa,"rfp13i") }
-      if("annotBySoft$File.Name" %in% names(setupSd)) {
-        sampleNames <- if(length(setupSd$annotBySoft$File.Name)==ncol(quant)) {    # try taking sampleNames from sdrf
-          basename(sub("\\.raw$|\\.Raw$|\\.RAW$","", setupSd$annotBySoft$File.Name)) } else colnames(abund)     # otherwise remain with colnames from main file
-        sampleNames <- wrMisc::trimRedundText(sampleNames, minNchar=2, spaceElim=TRUE, silent=silent, callFrom=fxNa, debug=debug)
-        colnames(quant) <- colnames(abund) <- sampleNames
-      } else  colnames(quant) <- sampleNames <- colnames(abund)
-      if(length(dim(counts)) >1 & length(counts) >0) colnames(counts) <- sampleNames
-
-    }
-    if(debug) {message(fxNa,"Read sample-meta data, rfp14"); rfp14 <- list(sdrf=sdrf,suplAnnotFile=suplAnnotFile,abund=abund, quant=quant,refLi=refLi,annot=annot,setupSd=setupSd,sampleNames=sampleNames)}
-
-    ## plot distribution of intensities
+    ## main plotting of distribution of intensities
     custLay <- NULL
-    if(is.numeric(plotGraph) & length(plotGraph) >0) {custLay <- as.integer(plotGraph); plotGraph <- TRUE} else {
-      if(!isTRUE(plotGraph)) plotGraph <- FALSE}
-    if(plotGraph) {
-      if(debug) {message(fxNa,"rfp15 .. length custLay ", length(custLay) )}
-      if(length(custLay) >0) graphics::layout(custLay) else {if(!identical(normalizeMeth,"none") & length(quant) >0) graphics::layout(1:2)}
-      ch1 <- try(graphics::par(mar=c(3, 3, 3, 1)), silent=TRUE)                          # mar: bot,le,top,ri
-      if(inherits(ch1, "try-error")) {plotGraph <- FALSE; message(fxNa,"UNABLE to graphical paramters !! Abandoning plot ! check current graphics device ...")} }      
-    if(plotGraph) {
-      if(length(graphTit) >0) message(fxNa,"Argument 'graphTit' is depreciated, please rather use 'tit'")
-      if(is.null(tit) & !is.null(graphTit)) tit <- graphTit     # for derpreciated argument
-      if(is.null(tit)) tit <- "Fragpipe quantification "
-      chGr <- try(find.package("wrGraph"), silent=TRUE)
-      chSm <- try(find.package("sm"), silent=TRUE)
-      misPa <- c(inherits(chGr, "try-error"), inherits(chSm, "try-error"))
-      titSu <- if(length(refLi) >0) paste0(c(" by ",if(length(refLiIni) >1) c(length(refLi)," selected lines") else c("'",refLiIni,"'")),collapse="")  else NULL
-      if(debug) { message(fxNa,"rfp16 .. misPa ", wrMisc::pasteC(misPa,quoteC="'") )}
-      if(any(misPa, na.rm=TRUE)) {
-        if(!silent) message(fxNa,"Missing package ",wrMisc::pasteC(c("wrGraph","sm")[which(misPa)],quoteC="'")," for drawing vioplots")
-        ## wrGraph not available : simple boxplot
-        graphics::boxplot(log2(abund), main=paste(tit,"(initial)",sep=" "), las=1, outline=FALSE)
-        graphics::abline(h=round(log2(stats::median(abund,na.rm=TRUE))) +c(-2:2)*3, lty=2, col=grDevices::grey(0.6))
-        ## plot normalized
-        if(identical(normalizeMeth, "none") | length(quant) <0) {
-          graphics::boxplot(quant, main=paste(tit," (",normalizeMeth,"-normalized",titSu,")"), las=1, outline=FALSE)
-          if(debug) {message(fxNa,"rfp17 .. dim quant: ", nrow(quant)," li and  ",ncol(quant)," cols; colnames : ",wrMisc::pasteC(colnames(quant))," ")}
-          graphics::abline(h=round(stats::median(quant, na.rm=TRUE)) +c(-2:2)*3, lty=2, col=grDevices::grey(0.6)) }
-      } else {                                            # wrGraph and sm are available
-        if(debug) {message(fxNa,"rfp18  print vioplotW "  )}
-        ch1 <- try(wrGraph::vioplotW(log2(abund), tit=paste(tit,"(initial)",sep=" "), wex=wex, silent=silent, callFrom=fxNa), silent=TRUE)
-        if(inherits(ch1, "try-error")) {plotGraph <- FALSE; message(fxNa,"UNABLE to plot vioplotW !!")
-        } else graphics::abline(h=round(stats::median(log2(abund), na.rm=TRUE)) +c(-2:2)*3, lty=2, col=grDevices::grey(0.6))
-        ## now normalized
-        if(debug) {message(fxNa,"rfp19  print norm vioplotW() ",identical(normalizeMeth,"none")," ou ", length(quant) <0)}
-        if(!identical(normalizeMeth,"none") | length(quant) >0) {
-          if(debug) {message(fxNa,"rfp20  print vioplotW() for normalized")}
-            ch1 <- try(wrGraph::vioplotW(quant, tit=paste(tit,", ",normalizeMeth,"-normalized",titSu), wex=wex, silent=silent, callFrom=fxNa), silent=TRUE)
-            if(inherits(ch1, "try-error")) {plotGraph <- FALSE; message(fxNa,"UNABLE to plot vioplotW !!")
-            } else graphics::abline(h=round(stats::median(quant, na.rm=TRUE)) +c(-2:2)*3, lty=2, col=grDevices::grey(0.6)) }
-        on.exit(graphics::par(mar=oparMar)) }            # restaure old settings
-    }
+    if(is.numeric(plotGraph) && length(plotGraph) >0) {custLay <- as.integer(plotGraph); plotGraph <- TRUE} else {
+        if(!isTRUE(plotGraph)) plotGraph <- FALSE}
+    if(plotGraph) .plotQuantDistr(abund=abund, quant=quant, custLay=custLay, normalizeMeth=normalizeMeth, softNa="FragPipe",
+      refLi=refLi, refLiIni=refLiIni, tit=titGraph, silent=silent, callFrom=fxNa, debug=debug)
+    if(debug) {message(fxNa,"Read sample-meta data, rfp15"); rfp15 <- list()}
+
 
     ## meta-data
-    notes <- c(inpFile=paFi, qmethod="Fragpipe", qMethVersion=if(length(infoDat) >0) unique(infoDat$Software.Revision) else NA,
+    notes <- c(inpFile=paFi, qmethod="FragPipe", qMethVersion=if(length(infoDat) >0) unique(infoDat$Software.Revision) else NA,
     	rawFilePath= if(length(infoDat) >0) infoDat$File.Name[1] else NA, normalizeMeth=normalizeMeth, call=match.call(),
       created=as.character(Sys.time()), wrProteo.version=utils::packageVersion("wrProteo"), machine=Sys.info()["nodename"])
     ## final output
     if(isTRUE(separateAnnot)) list(raw=abund, quant=quant, annot=annot, counts=counts, sampleSetup=setupSd, quantNotes=parametersD, notes=notes) else data.frame(quant,annot) }
 }
-
+    
